@@ -1,14 +1,13 @@
-""" 
+"""
    !--------------------------------------------------------------------------!
    ! LICENSE INFO:                                                            !
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
    !                                                                          !
-   !    Copyright (C) 2014, The localCIDER development team (current and      !
-   !                        former contributors): Alex Holehouse, James       !
-   !                        Ahad, Rahul K. Das.                               !
+   !    Copyright (C) 2014 - 2017                                             !
+   !    The localCIDER development team (current and former contributors)     !
+   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
    !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
    !    University in St. Louis. Please see the website for citation          !
@@ -40,29 +39,27 @@
    !                                                                          !
    !--------------------------------------------------------------------------!
 
-   
+
    File Description:
    ================
-   
-   This is the main package import file for the localCIDER package. 
+
+   This is the main package import file for the localCIDER package.
 
 """
 
 __all__ = ['sequenceParameters', 'plots']
 
-from backend.config import VERSION as localCIDER_version
-from backend.backendtools import status_message
-import sequenceParameters as sequenceParameters 
-import sequencePermutants as sequencePermutants
-import plots as plots
+from .backend.config import VERSION as localCIDER_version
+from .backend.backendtools import status_message
+from . import sequenceParameters as sequenceParameters
+from . import sequencePermutants as sequencePermutants
+from . import plots as plots
 
 # Explicit exception importing
-from backend.localciderExceptions import KeyFileException 
-from backend.localciderExceptions import PlottingException
-from backend.localciderExceptions import SequenceException
-from backend.localciderExceptions import SequenceFileParserException
-from backend.localciderExceptions import ResTableException
-from backend.localciderExceptions import WLException
+from .backend.localciderExceptions import KeyFileException
+from .backend.localciderExceptions import PlottingException
+from .backend.localciderExceptions import SequenceException
+from .backend.localciderExceptions import SequenceFileParserException
+from .backend.localciderExceptions import ResTableException
+from .backend.localciderExceptions import WLException
 status_message("localCIDER version " + localCIDER_version)
-
-
