@@ -4,11 +4,9 @@
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
-   !                                                                          !
-   !    Copyright (C) 2014, The LocalCIDER development team (current and      !
-   !                        former contributors): Alex Holehouse, James       !
-   !                        Ahad, Rahul K. Das.                               !
+   !    Copyright (C) 2014 - 2017                                             !
+   !    The localCIDER development team (current and former contributors)     !
+   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
    !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
    !    University in St. Louis. Please see the website for citation          !
@@ -39,11 +37,11 @@
    ! MAIN AUTHOR:   Alex Holehouse                                            !
    !                                                                          !
    !--------------------------------------------------------------------------!
- 
-   
+
+
    File Description:
    ================
-   
+
    This is the main package index for the backend package. backend holds all the
    inner guts of localCIDER, and represents functions that users should never
    call directly. Instead, users should import sequenceParameters or other modules
@@ -51,5 +49,3 @@
 
 
 """
- 
-
