@@ -1,14 +1,12 @@
-""" 
+"""
    !--------------------------------------------------------------------------!
    ! LICENSE INFO:                                                            !
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
-   !                                                                          !
-   !    Copyright (C) 2014, The localCIDER development team (current and      !
-   !                        former contributors): Alex Holehouse, James       !
-   !                        Ahad, Rahul K. Das.                               !
+   !    Copyright (C) 2014 - 2017                                             !
+   !    The localCIDER development team (current and former contributors)     !
+   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
    !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
    !    University in St. Louis. Please see the website for citation          !
@@ -40,19 +38,18 @@
    !                                                                          !
    !--------------------------------------------------------------------------!
 
-   
+
    File Description:
    ================
-   
+
    Package configuration info
 
 """
-## CONFIGURATION STUFF YOU MIGHT WANT TO CHANGE
+# CONFIGURATION STUFF YOU MIGHT WANT TO CHANGE
 HUSH_WARNINGS = False
-HUSH_STATUS   = False
-HUSH_ALL      = False
+HUSH_STATUS = False
+HUSH_ALL = True
 
 
 # DO NOT CHANGE ANYTHING BELOW THIS LINE
-VERSION="0.1.3"
-
+VERSION = "0.1.14"
