@@ -1,14 +1,12 @@
-""" 
+"""
    !--------------------------------------------------------------------------!
    ! LICENSE INFO:                                                            !
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
-   !                                                                          !
-   !    Copyright (C) 2014, The localCIDER development team (current and      !
-   !                        former contributors): Alex Holehouse, James       !
-   !                        Ahad, Rahul K. Das.                               !
+   !    Copyright (C) 2014 - 2017                                             !
+   !    The localCIDER development team (current and former contributors)     !
+   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
    !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
    !    University in St. Louis. Please see the website for citation          !
@@ -40,21 +38,24 @@
    !                                                                          !
    !--------------------------------------------------------------------------!
 
-   
+
    File Description:
    ================
-   
+
    Class which holds the properties of an amino acid residue
 
 """
 
+
 class Residue:
-    """ 
-       Residue class which defines the properties for each residue.       
     """
-    def __init__(self,name,letterCode3,letterCode1,hydropathy,charge):        
+       Residue class which defines the properties for each residue.
+    """
+
+    def __init__(self, name, letterCode3, letterCode1, hydropathy, charge, PPII_Hilser, PPII_Creamer, PPII_Kallenbach):
         self.name = name                      # full name     [glycine]
         self.letterCode3 = letterCode3        # 3 letter code [gly]
         self.letterCode1 = letterCode1        # 1 letter code [g]
         self.hydropathy = hydropathy          # hydropathy score
         self.charge = charge                  # charge
+        self.PPII = {'hilser':PPII_Hilser, 'creamer':PPII_Creamer, 'kallenbach': PPII_Kallenbach}
