@@ -1,14 +1,12 @@
-""" 
+"""
    !--------------------------------------------------------------------------!
    ! LICENSE INFO:                                                            !
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
-   !                                                                          !
-   !    Copyright (C) 2014, The localCIDER development team (current and      !
-   !                        former contributors): Alex Holehouse, James       !
-   !                        Ahad, Rahul K. Das.                               !
+   !    Copyright (C) 2014 - 2017                                             !
+   !    The localCIDER development team (current and former contributors)     !
+   !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
    !    localCIDER was developed in the lab of Rohit Pappu at Washington      !
    !    University in St. Louis. Please see the website for citation          !
@@ -43,7 +41,7 @@
 
    File Description:
    ================
-   
+
    Class constructs a querayable ResTable object which provides rapid
    for each amino acid's properties
 
@@ -52,11 +50,12 @@
 import csv
 import numpy as np
 
-from residue import Residue
-import data
-from data.aminoacids import THREE_TO_ONE, ONE_TO_THREE
+from .residue import Residue
+from . import data
+from .data.aminoacids import THREE_TO_ONE, ONE_TO_THREE
+
+from .localciderExceptions import ResTableException
 
-from localciderExceptions import ResTableException
 
 class ResTable:
     """ Class which holds data on amino acids as read from the data.aminoacids file
@@ -66,54 +65,52 @@ class ResTable:
     #...................................................................................#
     def __init__(self):
         """ Takes a filename and initializes the self.residue_table list
-            with the contents of a residue table file        
+            with the contents of a residue table file
         """
-        
+
         self.residue_table = {}
 
         residue_list = data.aminoacids.buildTable()
 
         for r in residue_list:
-            res = Residue(r[0],r[1],r[2],r[3],r[4])
+            res = Residue(r[0], r[1], r[2], r[3], r[4], r[5], r[6], r[7])
             self.residue_table[res.letterCode3] = res
 
-
     #...................................................................................#
-    def lookForRes(self,resCode):
+    def lookForRes(self, resCode):
         """ Returns a Residue objected defined by the resCode (can be
             three letter or one letter - we don't care!
         """
-        
+
         # if we're using a three letter code
         if len(resCode) == 1:
-            if resCode in ONE_TO_THREE.keys():
+            if resCode in list(ONE_TO_THREE.keys()):
                 return self.residue_table[ONE_TO_THREE[resCode]]
-                
+
         # if we're usin a one letter code
         elif len(resCode) == 3:
-            if resCode in THREE_TO_ONE.keys():
+            if resCode in list(THREE_TO_ONE.keys()):
                 return self.residue_table[resCode]
-        
+
         # if we got here we had an invalid AA code
-        raise ResTableException("Invalid amino acid code provided [" + str(resCode) +"]")
-            
+        raise ResTableException(
+            "Invalid amino acid code provided [" + str(resCode) + "]")
 
     #...................................................................................#
-    def lookUpHydropathy(self,resCode):
-        """ 
+    def lookUpHydropathy(self, resCode):
+        """
         Get an amino acid's hydropathy
         """
 
         res = self.lookForRes(resCode)
         return res.hydropathy
-        
 
     #...................................................................................#
-    def lookUpCharge(self,resCode):
-        """ 
+    def lookUpCharge(self, resCode):
+        """
         Get the charge on a residue (1/-1/0)
         """
-        
+
         # first check for reduced residue types (aka charge +/-/0)
         if(resCode == '+'):
             return 1
@@ -125,4 +122,19 @@ class ResTable:
             res = self.lookForRes(resCode)
             return res.charge
 
+    #...................................................................................#
+    def lookUpPPII(self, resCode, mode='hilser'):
+        """
+        Get an amino acid's PPII propensity as defined by Hilser, Creamer or Kallenbach. Note
+        the code automatically sets the input to lower case to make the input case insensitive. 
+        """
 
+        mode = mode.lower()
+
+        if mode not in ['hilser', 'creamer', 'kallenbach']:
+            raise KeyError('Mode is not one of hilser, creamer or kallenbach')
+            
+        res = self.lookForRes(resCode)
+        return res.PPII[mode]
+
+        
