@@ -1,20 +1,19 @@
-""" 
+"""
    !--------------------------------------------------------------------------!
    ! LICENSE INFO:                                                            !
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.3                                                         !
    !--------------------------------------------------------------------------!
-   
+
    File Description:
    ================
-   
+
    This is a file containing various plotting functions. Note that localCIDER
-   doesn't require these functions to work - the ability to plot things is 
+   doesn't require these functions to work - the ability to plot things is
    nice but not essential.
 
-   There are eight plotting functions which can be called, and are 
+   There are eight plotting functions which can be called, and are
    as follows
 
    >>> Show or save a single sequence on the diagam of states plot
@@ -39,8 +38,8 @@
 
 
    These functions can be called independently of other localCIDER
-   functionality, or you could calculate the fraction of positive and 
-   negative residues for a bunch of sequences and use these functions 
+   functionality, or you could calculate the fraction of positive and
+   negative residues for a bunch of sequences and use these functions
    independent of the localCIDER SequenceParameter objects.
 
    Note that for plotting linear sequence data (e.g. linear hydropathy,
@@ -48,11 +47,20 @@
 
 """
 
-from backend import plotting
+from .backend import plotting
 
 
 #...................................................................................#
-def show_single_phasePlot(fp, fn, label="", title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_single_phasePlot(
+        fp,
+        fn,
+        label="",
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states).
 
@@ -60,14 +68,14 @@ def show_single_phasePlot(fp, fn, label="", title="Diagram of states", legendOn=
     --------------------------------------------------------------------------------
     fp         | Fraction of positive residues
     fn         | Fraction of negative residues
-    
+
     label      | On-plot label of sequence (DEFAULT = no label)
     title      | Plot title (DEFAULT = "Diagram of states")
     legendOn   | Include the phase diagram region legend (DEFAULT = True)
     xLim       | Set upper limit for the x axis (DEFAULT = 1)
     yLim       | Set upper limit for the y axis (DEFAULT = 1)
     fontSize   | Set font size for the point labels (DEFAULT = 10)
-    getFig     | Returns a matplotlib figure object instead of simply displaying the 
+    getFig     | Returns a matplotlib figure object instead of simply displaying the
                | plot on the screen (DEFAULT = False)
 
     OUTPUT:
@@ -76,39 +84,72 @@ def show_single_phasePlot(fp, fn, label="", title="Diagram of states", legendOn=
     Nothing but a plot should be generated on screen
     """
 
-    return plotting.show_single_phasePlot(fp, fn, label, title, legendOn, xLim, yLim, fontSize, getFig)
-    
+    return plotting.show_single_phasePlot(
+        fp, fn, label, title, legendOn, xLim, yLim, fontSize, getFig)
+
 
 #...................................................................................#
-def save_single_phasePlot(fp, fn, filename, label="", title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_single_phasePlot(
+        fp,
+        fn,
+        filename,
+        label="",
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states).
 
     INPUT:
     --------------------------------------------------------------------------------
-    fp        | Fraction of positive residues
-    fn        | Fraction of negative residues
-    filename  | Path/name of file to save plot (.png is appended)
+    fp         | Fraction of positive residues
+    fn         | Fraction of negative residues
+    filename   | Path/name of file to save plot (.png is appended)
 
-    label     | On-plot label of sequence (DEFAULT = no label)
-    title     | Plot title (DEFAULT = "Diagram of states")
-    legendOn  | Include the phase diagram region legend (DEFAULT = True)
-    xLim      | Set upper limit for the x axis (DEFAULT = 1)
-    yLim      | Set upper limit for the x axis (DEFAULT = 1)
-    fontSize  | Set font size for the point labels (DEFAULT = 10)
+    label      | On-plot label of sequence (DEFAULT = no label)
+    title      | Plot title (DEFAULT = "Diagram of states")
+    legendOn   | Include the phase diagram region legend (DEFAULT = True)
+    xLim       | Set upper limit for the x axis (DEFAULT = 1)
+    yLim       | Set upper limit for the x axis (DEFAULT = 1)
+    fontSize   | Set font size for the point labels (DEFAULT = 10)
+    saveFormat | Defines the file formal to save plots as. This parameter
+                 is passed to matplotlibs savefig command which supports 
+                 the following filetypes: emf, eps, pdf, png, ps, raw, 
+                 rgba, svg, svgz. (DEFAULT = png)
 
-    
-    OUTPUT: 
+    OUTPUT:
     --------------------------------------------------------------------------------
     Nothing but a plot should be generated on screen
 
     """
 
-    plotting.save_single_phasePlot(fp, fn, filename, label, title, legendOn, xLim, yLim, fontSize)
+    plotting.save_single_phasePlot(
+        fp,
+        fn,
+        filename,
+        label,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        saveFormat)
 
 
 #...................................................................................#
-def show_multiple_phasePlot(fp_list, fn_list, label=[""], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        label=[""],
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plot multiple sequences on the same Pappu-Das phase plot (diagram of states).
 
@@ -116,28 +157,45 @@ def show_multiple_phasePlot(fp_list, fn_list, label=[""], title="Diagram of stat
     --------------------------------------------------------------------------------
     fp_list    | Fraction of positive residues
     fn_list    | Fraction of negative residues
-    
+
     label_list | On-plot label of sequence (DEFAULT = no label)
     title      | Plot title (DEFAULT = "Diagram of states")
     legendOn   | Include the phase diagram region legend (DEFAULT = True)
     xLim       | Set upper limit for the x axis (DEFAULT = 1)
     yLim       | Set upper limit for the x axis (DEFAULT = 1)
     fontSize   | Set font size for the point labels (DEFAULT = 10)
-    getFig     | Returns a matplotlib figure object instead of simply displaying the 
+    getFig     | Returns a matplotlib figure object instead of simply displaying the
                | plot on the screen (DEFAULT = False)
-    
 
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
-    Nothing, but a plot with multiple points should appear on the screen 
+    Nothing, but a plot with multiple points should appear on the screen
 
     """
 
-    return plotting.show_multiple_phasePlot(fp_list, fn_list, label, title, legendOn, xLim, yLim, fontSize, getFig)
+    return plotting.show_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        label,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        getFig)
 
 
 #...................................................................................#
-def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_multiple_phasePlot2(
+        SeqParam_list,
+        label_list=[],
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states). This function takes
     SequenceParameter objects rather than raw values
@@ -145,21 +203,21 @@ def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of sta
     INPUT:
     --------------------------------------------------------------------------------
     SeqParam_list | list of sequence parameter objects
-    
+
     label         | On-plot label of sequence (DEFAULT = no label)
     title         | Plot title (DEFAULT = "Diagram of states")
     legendOn      | Include the phase diagram region legend (DEFAULT = True)
     xLim          | Set upper limit for the x axis (DEFAULT = 1)
     yLim          | Set upper limit for the y axis (DEFAULT = 1)
     fontSize      | Set font size for the point labels (DEFAULT = 10)
-    getFig        | Returns a matplotlib figure object instead of simply displaying the 
+    getFig        | Returns a matplotlib figure object instead of simply displaying the
                   | plot on the screen (DEFAULT = False)
-       
 
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
-    Nothing, but a plot with multiple points should appear on the screen 
-    
+    Nothing, but a plot with multiple points should appear on the screen
+
     """
 
     # construct the fraction positive and negative vectors
@@ -169,11 +227,30 @@ def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of sta
         fp_list.append(seq.get_fraction_positive())
         fn_list.append(seq.get_fraction_negative())
 
-    return plotting.show_multiple_phasePlot(fp_list, fn_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
-    
+    return plotting.show_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        getFig)
+
 
 #...................................................................................#
-def save_multiple_phasePlot(fp_list, fn_list, filename, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        filename,
+        label_list=[],
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
     Plot multiple sequences on the same Pappu-Das phase plot (diagram of states) and save that file
 
@@ -182,44 +259,71 @@ def save_multiple_phasePlot(fp_list, fn_list, filename, label_list=[], title="Di
     fp_list    | Fraction of positive residues
     fn_list    | Fraction of negative residues
     filename   | name of file to save (.png is appended)
-    
+
     label_list | On-plot label of sequence (DEFAULT = no label)
     title      | Plot title (DEFAULT = "Diagram of states")
     legendOn   | Include the phase diagram region legend (DEFAULT = True)
     xLim       | Set upper limit for the x axis (DEFAULT = 1)
     yLim       | Set upper limit for the y axis (DEFAULT = 1)
     fontSize   | Set font size for the point labels (DEFAULT = 10)
+    saveFormat | Defines the file formal to save plots as. This parameter
+                 is passed to matplotlibs savefig command which supports 
+                 the following filetypes: emf, eps, pdf, png, ps, raw, 
+                 rgba, svg, svgz. (DEFAULT = png)
 
-    
-    OUTPUT: 
+
+
+    OUTPUT:
     --------------------------------------------------------------------------------
     No output, but if succesful a file with filename is generated with the associated plot
 
     """
 
-    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
+    plotting.save_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        filename,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        saveFormat)
 
 
 #...................................................................................#
-def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_multiple_phasePlot2(
+        SeqParam_list,
+        filename,
+        label_list=[],
+        title="Diagram of states",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
-    Plot multiple sequences on the same Pappu-Das phase plot (diagram of states) and save that file. 
+    Plot multiple sequences on the same Pappu-Das phase plot (diagram of states) and save that file.
     This function takes SequenceParameter objects rather than raw values.
 
     INPUT:
     --------------------------------------------------------------------------------
     SeqParam_list | list of sequence parameter objects
     filename      | name of file to save (.png is appended)
-    
+
     label_list    | On-plot label of sequence (DEFAULT = no label)
     title         | Plot title (DEFAULT = "Diagram of states")
     legendOn      | Include the phase diagram region legend (DEFAULT = True)
     xLim          | Set upper limit for the x axis (DEFAULT = 1)
     yLim          | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize      | Set font size for the point labels (DEFAULT = 10)    
-    
+    fontSize      | Set font size for the point labels (DEFAULT = 10)
+    saveFormat    | Defines the file formal to save plots as. This parameter
+                    is passed to matplotlibs savefig command which supports 
+                    the following filetypes: emf, eps, pdf, png, ps, raw, 
+                    rgba, svg, svgz. (DEFAULT = png)
 
-    OUTPUT: 
+    OUTPUT:
     --------------------------------------------------------------------------------
     No output, but if succesful a file with filename is generated with the associated plot
 
@@ -232,17 +336,36 @@ def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diag
         fp_list.append(seq.get_fraction_positive())
         fn_list.append(seq.get_fraction_negative())
 
-    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
+    plotting.save_multiple_phasePlot(
+        fp_list,
+        fn_list,
+        filename,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        saveFormat)
 
 
 ####################################################
 ##
-##             UVERSKY PLOTS BELOW
+# UVERSKY PLOTS BELOW
 ##
 ####################################################
 
 #...................................................................................#
-def show_single_uverskyPlot(hydropathy, mean_net_charge, label="", title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_single_uverskyPlot(
+        hydropathy,
+        mean_net_charge,
+        label="",
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plots a single sequence on the Uversky plot (hydropathy vs. mean net charge)
 
@@ -250,29 +373,48 @@ def show_single_uverskyPlot(hydropathy, mean_net_charge, label="", title="Uversk
     --------------------------------------------------------------------------------
     hydropathy      | Mean hydropathy for sequence
     mean_net_charge | Absolute magnitude of the protein's net charge divided by sequence length
-    
+
     label           | On-plot label of sequence (DEFAULT = no label)
     title           | Plot title (DEFAULT = "Uversky plot")
     legendOn        | Include the phase diagram region legend (DEFAULT = True)
     xLim            | Set upper limit for the x axis (DEFAULT = 1)
     yLim            | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize        | Set font size for the point labels (DEFAULT = 10)    
-    getFig          | Returns a matplotlib figure object instead of simply displaying the 
+    fontSize        | Set font size for the point labels (DEFAULT = 10)
+    getFig          | Returns a matplotlib figure object instead of simply displaying the
                     | plot on the screen (DEFAULT = False)
 
 
 
-    OUTPUT: 
+    OUTPUT:
     --------------------------------------------------------------------------------
     Nothing, but an annotated Uversky plot should be generated on screen
 
     """
 
-    return plotting.show_single_uverskyPlot(hydropathy, mean_net_charge, label, title, legendOn, xLim, yLim, fontSize, getFig)
+    return plotting.show_single_uverskyPlot(
+        hydropathy,
+        mean_net_charge,
+        label,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        getFig)
 
 
 #...................................................................................#
-def save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label="", title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_single_uverskyPlot(
+        hydropathy,
+        mean_net_charge,
+        filename,
+        label="",
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
     Plots a single sequence on the Uversky plot (hydropathy vs. mean net charge) and save it to 'filename' (.png is
     appended).
@@ -289,19 +431,42 @@ def save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label="", tit
     xLim            | Set upper limit for the x axis (DEFAULT = 1)
     yLim            | Set upper limit for the y axis (DEFAULT = 1)
     fontSize        | Set font size for the point labels (DEFAULT = 10)
-    
+    saveFormat      | Defines the file formal to save plots as. This parameter
+                      is passed to matplotlibs savefig command which supports 
+                      the following filetypes: emf, eps, pdf, png, ps, raw, 
+                      rgba, svg, svgz. (DEFAULT = png)
 
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
     Nothing but single uversky plot should be saved to disk
 
     """
 
-    plotting.save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label, title, legendOn, xLim, yLim, fontSize)
+    plotting.save_single_uverskyPlot(
+        hydropathy,
+        mean_net_charge,
+        filename,
+        label,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        saveFormat)
 
 
 #...................................................................................#
-def show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        label_list=[],
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and shows the plot on the screen.
 
@@ -309,27 +474,44 @@ def show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list=
     --------------------------------------------------------------------------------
     hydropathy_list      | List of proteins' mean hydropathy
     mean_net_charge_list | List of the absolute magnitude of the protein's net charge divided by sequence length
-    
+
     label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
     xLim                 | Set upper limit for the x axis (DEFAULT = 1)
     yLim                 | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize             | Set font size for the point labels (DEFAULT = 10)    
-    getFig               | Returns a matplotlib figure object instead of simply displaying the 
+    fontSize             | Set font size for the point labels (DEFAULT = 10)
+    getFig               | Returns a matplotlib figure object instead of simply displaying the
                          | plot on the screen (DEFAULT = False)
 
-    
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
-    Nothing, but a Uversky plot with multiple points should appear on the screen 
+    Nothing, but a Uversky plot with multiple points should appear on the screen
 
     """
-    return plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
+    return plotting.show_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        getFig)
 
 
 #...................................................................................#
-def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
+def show_multiple_uverskyPlot2(
+        SeqParam_list,
+        label_list=[],
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        getFig=False):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and shows the plot on the screen.
     This function takes a list of SequenceParameter objects instead of the actual values
@@ -337,20 +519,20 @@ def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot
     INPUT:
     --------------------------------------------------------------------------------
     SeqParam_list        | List of sequence parameter objects
-    
+
     label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
     xLim                 | Set upper limit for the x axis (DEFAULT = 1)
     yLim                 | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize             | Set font size for the point labels (DEFAULT = 10)    
-    getFig               | Returns a matplotlib figure object instead of simply displaying the 
+    fontSize             | Set font size for the point labels (DEFAULT = 10)
+    getFig               | Returns a matplotlib figure object instead of simply displaying the
                          | plot on the screen (DEFAULT = False)
 
-    
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
-    Nothing, but a Uversky plot with multiple points should appear on the screen 
+    Nothing, but a Uversky plot with multiple points should appear on the screen
 
     """
 
@@ -358,14 +540,34 @@ def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot
     hydropathy_list = []
     mean_net_charge_list = []
     for seq in SeqParam_list:
-        hydropathy_list.append(seq.get_uversky_hydrophobicity())
+
+        hydropathy_list.append(seq.get_uversky_hydropathy())
         mean_net_charge_list.append(seq.get_mean_net_charge())
 
-    return plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
+    return plotting.show_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        getFig)
 
 
 #...................................................................................#
-def save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        filename,
+        label_list=[],
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and saves that plot to 'filename' (.png
     is appended).
@@ -375,59 +577,94 @@ def save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, l
     hydropathy           | List of mean hydropathies for sequences
     mean_net_charge_list | List of the absolute magnitude of the protein's net charge divided by sequence length
     filename             | Path/name of file to save plot (.png is appended)
-   
+
     label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
     xLim                 | Set upper limit for the x axis (DEFAULT = 1)
     yLim                 | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize             | Set font size for the point labels (DEFAULT = 10)    
-    
+    fontSize             | Set font size for the point labels (DEFAULT = 10)
+    saveFormat           | Defines the file formal to save plots as. This parameter
+                           is passed to matplotlibs savefig command which supports 
+                           the following filetypes: emf, eps, pdf, png, ps, raw, 
+                           rgba, svg, svgz. (DEFAULT = png)
 
-    OUTPUT: 
+
+
+    OUTPUT:
     --------------------------------------------------------------------------------
     Nothing, but a Uversky plot with multiple points should be saved to the 'filename', where filename
     defines the name of a file/path for saving
 
     """
 
-    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
+    plotting.save_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        filename,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize,
+        saveFormat)
 
 
 #...................................................................................#
-def save_multiple_uverskyPlot2(SeqParam_list, filename, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
+def save_multiple_uverskyPlot2(
+        SeqParam_list,
+        filename,
+        label_list=[],
+        title="Uversky plot",
+        legendOn=True,
+        xLim=1,
+        yLim=1,
+        fontSize=10,
+        saveFormat='png'):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and saves that plot to 'filename' (.png
-    is appended). This function takes SequenceParameter objects instead of list of hydrophobicity and mean_net_charge
+    is appended). This function takes SequenceParameter objects instead of list of hydropathy and mean_net_charge
     values
-    
+
     INPUT:
     --------------------------------------------------------------------------------
     SeqParam_list   | List of sequence parameter objects
     filename        | Path/name of file to save plot (.png is appended)
-   
+
     label           | On-plot label of sequence (DEFAULT = no label)
     title           | Plot title (DEFAULT = "Uversky plot")
     legendOn        | Include the phase diagram region legend (DEFAULT = True)
     xLim            | Set upper limit for the x axis (DEFAULT = 1)
     yLim            | Set upper limit for the y axis (DEFAULT = 1)
-    fontSize        | Set font size for the point labels (DEFAULT = 10)     
-    
+    fontSize        | Set font size for the point labels (DEFAULT = 10)
+    saveFormat      | Defines the file formal to save plots as. This parameter
+                      is passed to matplotlibs savefig command which supports 
+                      the following filetypes: emf, eps, pdf, png, ps, raw, 
+                      rgba, svg, svgz. (DEFAULT = png)
 
-    OUTPUT: 
+
+    OUTPUT:
     --------------------------------------------------------------------------------
     Nothing, but a Uversky plot with multiple points should be saved to the 'filename', where filename
     defines the name of a file/path for saving
-    
+
     """
 
     # construct the fraction positive and negative vectors
     hydropathy_list = []
     mean_net_charge_list = []
     for seq in SeqParam_list:
-        hydropathy_list.append(seq.get_uversky_hydrophobicity())
+        hydropathy_list.append(seq.get_uversky_hydropathy())
         mean_net_charge_list.append(seq.get_mean_net_charge())
 
-
-    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
-
+    plotting.save_multiple_uverskyPlot(
+        hydropathy_list,
+        mean_net_charge_list,
+        filename,
+        label_list,
+        title,
+        legendOn,
+        xLim,
+        yLim,
+        fontSize)
